==> nextcloud-14.0.13.zip: nextcloud/apps/dav/l10n/sk.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendár",
    "Todos" : "Úlohy",
    "Personal" : "Osobné",
    "{actor} created calendar {calendar}" : "[actor] vytvoril kalendár [calendar]",
    "You created calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
    "{actor} deleted calendar {calendar}" : "[actor] zmazal kalendár [calendar]",
    "You deleted calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
    "{actor} updated calendar {calendar}" : "[actor] upravil kalendár [calendar]",
    "You updated calendar {calendar}" : "Upravili ste kalendár {calendar}",
    "You shared calendar {calendar} as public link" : "Sprístupnili ste kalendár {calendar}  ako verejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstránili ste verejný odkaz pre kalendár {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} vám sprístupnil kalendár {calendar}",
    "You shared calendar {calendar} with {user}" : "Sprístupnili ste kalendár {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} sprístupnil kalendár {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} vám prestal sprístupňovať kalendár {calendar}",
    "You unshared calendar {calendar} from {user}" : "Prestali ste sprístupňovať kalendár {calendar} od používateľa {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zrušil zdieľanie kalendára {calendar} s používateľom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zrušil zdieľanie kalendára {calendar} so sebou samým",
    "You shared calendar {calendar} with group {group}" : "Sprístupnili ste kalendár {calendar} so skupinou {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} vyzdieľal kalendár {calendar} so skupinou {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili ste zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  zrušil zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvoril udalosť {event} v kalendári {calendar}",
    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť {event} v kalendári {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} zmazal udalosť {event} from z kalendára {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť {event} z kalendára {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}  aktualizoval udalosť {event} v kalendári {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizovali ste udalosť {event} v kalendári {calendar}",
    "Busy" : "Zaneprázdnený",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvoril úlohu {todo} v {calendar}",
    "You created todo {todo} in list {calendar}" : "Vytvorili ste úlohu {todo} v {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} zmazal úlohu {todo} z {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Zmazali ste úlohu {todo} z {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} upravil úlohu {todo} v {calendar}",
    "You updated todo {todo} in list {calendar}" : "Upravili ste úlohu {todo} v {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyriešil úlohu {todo} v {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyriešili ste úlohu {todo} v {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otvoril úlohu {todo} v {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otvorili ste znovu úlohu {todo} v {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>kalendár</strong> bol upravený",
    "A calendar <strong>event</strong> was modified" : "<strong>Udalosť</strong> v kalendári bola upravená",
    "A calendar <strong>todo</strong> was modified" : "<strong>Pripomienka</strong> v kalendári bola upravená",
    "Contact birthdays" : "Narodeniny kontaktu",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Invitation canceled" : "Pozvánka bola zrušená",
    "Hello %s," : "Ahoj %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Stretnutie »%1$s« s %2$s bolo zrušené.",
    "Invitation updated" : "Pozvánka bola aktualizovaná",
    "The meeting »%1$s« with %2$s was updated." : "Stretnutie »%1$s« s %2$s bolo aktualizované.",
    "%1$s invited you to »%2$s«" : "%1$s vám poslal pozvánku na »%2$s«",
    "When:" : "Kedy:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Link:" : "Odkaz:",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "More options …" : "Ďalšie nastavenia ...",
    "More options at %s" : "Ďalšie nastavenia %s",
    "Contacts" : "Kontakty",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ak chcete používať CalDAV alebo CardDAV v iOS alebo macOS, musí byť %s nakonfigurovaný na používanie HTTPS.",
    "Configures a CalDAV account" : "Nakonfiguruje účet CalDAV",
    "Configures a CardDAV account" : "Nakonfiguruje účet CardDAV",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Koncový bod WebDAV",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
    "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
    "Are you accepting the invitation?" : "Príjmate pozvánku?",
    "Tentative" : "Neistý",
    "Save" : "Uložiť",
    "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne.",
    "Calendar server" : "Kalendárový server",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Tiež nainštalujte {calendarappstoreopen}apku Kalendár{linkclose} alebo {calendardocopen}pripojte svoj počítač a smartfón pre synchronizáciu ↗{linkclose}.",
    "Send invitations to attendees" : "Odoslanie pozvánok účastníkom",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Uistite sa, že ste správne nastavili {emailopen}e-mailový server{linkclose}.",
    "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
    "Birthday calendars will be generated by a background job." : "Narodeninové kalendáre budú generované úlohou na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Preto nebudú dostupné hneď po povolení, ale zobrazia sa po určitom čase",
    "%s via %s" : "%s cez %s",
    "The meeting »%s« with %s was canceled." : "Stretnutie »%s« s %s bolo zrušené.",
    "The meeting »%s« with %s was updated." : "Stretnutie »%s« s %s bolo aktualizované.",
    "%s invited you to »%s«" : "%s vám poslal pozvánku na »%s«",
    "Please make sure to properly set up the email settings above." : "Uistite sa, že máte správne nastavené vyššie uvedené nastavenia e-mailu."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-18.0.6.zip: nextcloud/apps/dav/l10n/sk.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendár",
    "Todos" : "Úlohy",
    "Personal" : "Osobné",
    "{actor} created calendar {calendar}" : "[actor] vytvoril kalendár [calendar]",
    "You created calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
    "{actor} deleted calendar {calendar}" : "[actor] zmazal kalendár [calendar]",
    "You deleted calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
    "{actor} updated calendar {calendar}" : "[actor] upravil kalendár [calendar]",
    "You updated calendar {calendar}" : "Upravili ste kalendár {calendar}",
    "You shared calendar {calendar} as public link" : "Sprístupnili ste kalendár {calendar}  ako verejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstránili ste verejný odkaz pre kalendár {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} vám sprístupnil kalendár {calendar}",
    "You shared calendar {calendar} with {user}" : "Sprístupnili ste kalendár {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} sprístupnil kalendár {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} vám prestal sprístupňovať kalendár {calendar}",
    "You unshared calendar {calendar} from {user}" : "Prestali ste sprístupňovať kalendár {calendar} od používateľa {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zrušil zdieľanie kalendára {calendar} s používateľom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zrušil zdieľanie kalendára {calendar} so sebou samým",
    "You shared calendar {calendar} with group {group}" : "Sprístupnili ste kalendár {calendar} so skupinou {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} vyzdieľal kalendár {calendar} so skupinou {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili ste zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  zrušil zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvoril udalosť {event} v kalendári {calendar}",
    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť {event} v kalendári {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} zmazal udalosť {event} from z kalendára {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť {event} z kalendára {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}  aktualizoval udalosť {event} v kalendári {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizovali ste udalosť {event} v kalendári {calendar}",
    "Busy" : "Zaneprázdnený",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvoril úlohu {todo} v {calendar}",
    "You created todo {todo} in list {calendar}" : "Vytvorili ste úlohu {todo} v {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} zmazal úlohu {todo} z {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Zmazali ste úlohu {todo} z {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} upravil úlohu {todo} v {calendar}",
    "You updated todo {todo} in list {calendar}" : "Upravili ste úlohu {todo} v {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyriešil úlohu {todo} v {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyriešili ste úlohu {todo} v {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otvoril úlohu {todo} v {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otvorili ste znovu úlohu {todo} v {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>kalendár</strong> bol upravený",
    "A calendar <strong>event</strong> was modified" : "<strong>Udalosť</strong> v kalendári bola upravená",
    "A calendar <strong>todo</strong> was modified" : "<strong>Pripomienka</strong> v kalendári bola upravená",
    "Death of %s" : "Dátum úmrtia %s",
    "Contact birthdays" : "Narodeniny kontaktu",
    "Calendar:" : "Kalendár:",
    "Date:" : "Dátum:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Untitled event" : "Udalosť bez názvu",
    "_%n year_::_%n years_" : ["%n rokov","%n rokov","%n rokov","%n rokov"],
    "_%n month_::_%n months_" : ["%n mesiac","%n mesiace","%n mesiacov","%n mesiacov"],
    "_%n day_::_%n days_" : ["%n deň","%n dni","%n dní","%n dní"],
    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodín","%n hodín"],
    "_%n minute_::_%n minutes_" : ["%n minúta","%n minúty","%n minút","%n minút"],
    "%s (in %s)" : "%s (v %s)",
    "%s (%s ago)" : "%s (pred %s)",
    "Calendar: %s" : "Kalendár: %s",
    "Date: %s" : "Dátum: %s",
    "Description: %s" : "Popis: %s",
    "Where: %s" : "Kde: %s",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Invitation canceled" : "Pozvánka bola zrušená",
    "Hello %s," : "Ahoj %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Stretnutie »%1$s« s %2$s bolo zrušené.",
    "Invitation updated" : "Pozvánka bola aktualizovaná",
    "The meeting »%1$s« with %2$s was updated." : "Stretnutie »%1$s« s %2$s bolo aktualizované.",
    "%1$s invited you to »%2$s«" : "%1$s vám poslal pozvánku na »%2$s«",
    "When:" : "Kedy:",
    "Link:" : "Odkaz:",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "More options …" : "Ďalšie nastavenia ...",
    "More options at %s" : "Ďalšie nastavenia %s",
    "Contacts" : "Kontakty",
    "System in maintenance mode." : "Systém je v režime údržby.",
    "Upgrade needed" : "Je potrebná aktualizácia",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ak chcete používať CalDAV alebo CardDAV v iOS alebo macOS, musí byť %s nakonfigurovaný na používanie HTTPS.",
    "Configures a CalDAV account" : "Nakonfiguruje účet CalDAV",
    "Configures a CardDAV account" : "Nakonfiguruje účet CardDAV",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Koncový bod WebDAV",
    "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
    "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
    "Are you accepting the invitation?" : "Príjmate pozvánku?",
    "Tentative" : "Neistý",
    "Save" : "Uložiť",
    "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne.",
    "Calendar server" : "Kalendárový server",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Tiež nainštalujte {calendarappstoreopen}apku Kalendár{linkclose} alebo {calendardocopen}pripojte svoj počítač a smartfón pre synchronizáciu ↗{linkclose}.",
    "Send invitations to attendees" : "Odoslanie pozvánok účastníkom",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Uistite sa, že ste správne nastavili {emailopen}e-mailový server{linkclose}.",
    "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
    "Birthday calendars will be generated by a background job." : "Narodeninové kalendáre budú generované úlohou na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Preto nebudú dostupné hneď po povolení, ale zobrazia sa po určitom čase",
    "Send notifications for events" : "Zaslať upozornenia na udalosti",
    "Notifications are sent via background jobs, so these must occur often enough." : "Upozornenia sa odosielajú prostredníctvom úloh na pozadí - preto je potrebné, aby tieto prebiehali dostatočne často.",
    "Enable notifications for events via push" : "Zapnúť oznámenia o udalostiach prostredníctvom technológie push.",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Oznámenia sa budú odosielať prostredníctvom úloh na pozadí - preto je potrebné, aby tieto prebiehali dostatočne často."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
